@@ -1,6 +1,7 @@
 #! /usr/bin/env python
+# coding: utf8
 
-# $Id: test_TableParser.py 4564 2006-05-21 20:44:42Z wiemann $
+# $Id: test_TableParser.py 7313 2012-01-11 20:28:57Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -38,6 +39,18 @@ totest['grid_tables'] = [
  [],
  [[(0, 0, 1, ['A table with']),
    (0, 0, 1, ['two columns.'])]])],
+# Combining chars in grid tables still fail
+# [u"""\
+# +--------------+------------------+
+# | A tāble w̅ith | comb̲ining chars. |
+# +--------------+------------------+
+# """,
+# [(0, 0, 2, 15, [u'A table with']),
+#  (0, 15, 2, 30, [u'combining chars.'])],
+# ([14, 14],
+#  [],
+#  [[(0, 0, 1, [u'A table with']),
+#    (0, 0, 1, [u'combining chars.'])]])],
 ["""\
 +--------------+-------------+
 | A table with | two columns |
@@ -184,10 +197,10 @@ totest['grid_tables'] = [
 | That's bad. |                 |
 +-------------+-----------------+
 """,
-'TableMarkupError: Multiple head/body row separators in table '
-'(at line offset 2 and 4); only one allowed.',
-'TableMarkupError: Multiple head/body row separators in table '
-'(at line offset 2 and 4); only one allowed.'],
+'TableMarkupError: Multiple head/body row separators '
+'(table lines 3 and 5); only one allowed.',
+'TableMarkupError: Multiple head/body row separators '
+'(table lines 3 and 5); only one allowed.'],
 ["""\
 +-------------------------------------+
 |                                     |
