@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_tables.py 6010 2009-07-05 15:29:02Z goodger $
+# $Id: test_tables.py 7463 2012-06-22 19:49:51Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -12,7 +12,6 @@ from __init__ import DocutilsTestSupport
 
 import os
 import csv
-from docutils._compat import u_prefix
 from docutils.parsers.rst.directives import tables
 
 
@@ -49,6 +48,7 @@ totest['table'] = [
 ["""\
 .. table:: Truth table for "not"
    :class: custom
+   :name:  tab:truth.not
 
    =====  =====
      A    not A
@@ -59,7 +59,7 @@ totest['table'] = [
 """,
 """\
 <document source="test data">
-    <table classes="custom">
+    <table classes="custom" ids="tab-truth-not" names="tab:truth.not">
         <title>
             Truth table for "not"
         <tgroup cols="2">
@@ -557,11 +557,11 @@ u"""\
     <system_message level="4" line="1" source="test data" type="SEVERE">
         <paragraph>
             Problems with "csv-table" directive path:
-            [Errno 2] No such file or directory: %s'bogus.csv'.
+            [Errno 2] No such file or directory: 'bogus.csv'.
         <literal_block xml:space="preserve">
             .. csv-table:: no such file
                :file: bogus.csv
-""" % u_prefix],
+"""],
 # note that this output is rewritten below for certain python versions
 ["""\
 .. csv-table:: bad URL
@@ -1070,18 +1070,6 @@ totest['list-table'] = [
 ]
 
 
-if csv:
-    # Rewrite csv tests that depend on the output of IOError as it is
-    # platform-dependent before python 2.4 for a unicode path.
-    # Here only needed for python 2.3 on non-windows
-    import sys
-    if sys.version_info < (2, 4) and not sys.platform.startswith('win'):
-        for i in range(len(totest['csv-table'])):
-            if totest['csv-table'][i][1].find("u'bogus.csv'") != -1:
-                totest['csv-table'][i][1] = totest['csv-table'][i][1].replace(
-                        "u'bogus.csv'", "'bogus.csv'")
-
-
 if __name__ == '__main__':
     import unittest
     unittest.main(defaultTest='suite')
